<?
	/*
	* SIMPLE PHOTO BROWSER:
	* This is a simple drop in display tool for small groups of images
	* it is not intended to replace a album for thousands of images, it
	* simply shows 20 or 30 images one after the other.
	*
	* It is compatible with mod_rewrite and can use templates to fit 
	* with your own designs.  You can change the appearance of some of the
	* elements using stylesheets, I am not a CSS guru though so they may
	* not be the optimal way of doing things.
	*
	* The following variables are supported in the templates
	*   image	the file name of the image
	*   text	the text associated with this image
	*   width	the image width
	*   height      the image height
	*   index       a simple navigation bar
	*   nexturl     url to the next image
	*   prevurl     url to the previous image
	*   theme       the name of the current theme
	*
	* Mod rewrite rules thats needed should look like this:
	*   RewriteRule ^([^\.\?/]+).jpg$      index.php?img=$1.jpg       [QSA]
	* 
	* Will take requests for dir/file.jpg and call index.php?img=file.jpg
	* setting have_mod_rewrite below will result in all url's being 
	* generated in a way compatible with the above rule
	*
	* SETUP:
	* - Copy distribution files into a directory of your choice
	* - Set up the .htaccess, a sample is provided, set have_mod_rewrite
	* - drop the images into the img/ directory
	* - create a file list, this can be as simple as 'ls > list.txt', the 
	*   order in this file will be followed, so you can enforce a display
	*   order by fiddling the list
	* - set captions for images by creating text in img/file.jpg.txt
	* - choose a theme or create your own, look in the themes/ directory
	* - test it in your browser
	* 
	* CONTACT:
	* Written by R.I.Pienaar <spb-contact@devco.net>
	*
	* DOWNLOAD:
	* New versions can be found on http://www.devco.net/
	*
	* $Id: index.php,v 1.2 2004/08/28 10:12:23 rip Exp $
	* $Name: REL_1_0 $
	*/

	$have_mod_rewrite = 1;
	$file_list = "img/list.txt";
	$theme = "white";

	require("html-lib.php");

	// does the file list exist?
	if (is_file($file_list)) {
		$handle = fopen($file_list, "r");
	} else {
		print ("list file found: $file_list");
		exit();
	}	

	// load the list file into an array
	$list = array();
	while (!feof($handle)) {
		$string = getLine($handle);
		if ($string != "") {
			array_push($list, $string);
		}
	}

	// how many images in the list
	$count = count($list) - 1;

	// file names of first and last images in the list
	$last = $list[$count];
	$first = $list[0];

	// file in img parameter will be showed, or the first one in the list
	if (isset($_GET[img])) {
		$fileToShow = $_GET[img];
	} else {
		$fileToShow = $list[0];
	}

	// where in the list is the file to show
	$idx = array_search($fileToShow, $list);

	// array_search returns 0 if it does not find the entry
	// however if the entry is the first in the list then it also
	// returns 0, how lame.  Hack around this by checking that
	// we arent trying to display the first entry in the list
	// along with the check for failure of array_search()
	if (($idx == FALSE) and ($fileToShow != $list[0])) {
		print ("File not found in list: '$fileToShow'");
		exit();
	} else {
		// first image? last one is previous
		if ($idx == "0") {
			$previous = $last;
			$previdx = $count;
		} else {
			$previous = $list[$idx-1];
			$previdx = $idx - 1;
		}	

		// the file name we are showing
		$show = $list[$idx];

		// if its the last image in the list, then next wil be the
		// first image in the list
		if ($idx == $count) {
			$next = $first;
			$nextidx = 0;
		} else {
			$next = $list[$idx+1];
			$nextidx = $idx + 1;
		}

		// load the text, if any
		if (is_file("img/$show.txt")) {
			$th = fopen("img/$show.txt", "r");
			$text = fread($th, 4096);
		} else {
			$text = "";
		}

		// get the dimensions
		$dimensions = getimagesize("img/$show");

		// build the navigation index
		$index = buildIndex($list, $idx, $nextidx, $previdx, $have_mod_rewrite);
	}

	// show it
	showImage($show, $next, $previous, $text, $dimensions, $index, $theme, $have_mod_rewrite);
	exit();


	// builds a simple navigation bar that will look something like this
	//
	// <span class="strip"><a href="image1.jpg">1</a></span>
	//     <span class="stripcurrent">2</span>
	//     <span class="strip"><a href="image3.jpg">3</a></span>
	//
	// You can put frames, borders etc around the nav using CSS
	function buildIndex($list, $current, $next, $previous, $rewrite) {
		for ($i = 0; $i < count($list); $i++) {
			if ($rewrite == 1) {
				$url = $list[$i];
			} else {
				$url = $REQUEST_URI . "?img=$list[$i]";
			}

			if ($current != $i) {
				$html = $html . "<span class=\"strip\"><a href=\"$url\">" . ($i + 1) . "</a></span>";
			} else {
				$html = $html . "<span class=\"stripcurrent\">" . ($i + 1) . "</span>";
			}	
		}

		return($html);
	}

	// loads the template, replace some values and send the result to the
	// browser
	function showImage($file, $next, $previous, $text, $size, $indexHtml, $theme, $rewrite) {
		$templ = new Template("themes/$theme/image.templ");
		
		$templ->Set("image", $file);
		$templ->Set("text", $text);
		$templ->Set("width", "$size[0]");
		$templ->Set("height", "$size[1]");
		$templ->Set("index", $indexHtml);
		$templ->Set("theme", $theme);

		if ($rewrite == 1) {
			$templ->Set("nexturl", $next);
			$templ->Set("prevurl", $previous);
		} else {
			$templ->Set("nexturl", $REQUEST_URI . "?img=" . $next);
			$templ->Set("prevurl", $REQUEST_URI . "?img=" . $previous);
		}

		$templ->Send();
	}

	// reads a line from a file WITHOUT the \n or \r
	function getLine($file) {
		// iterate over each character in line.
		while (false !== ($character = fgetc($file)))
		{
			// check for end of line.
			if (($character == "\n") or ($character == "\r")) {
				// end of line, so stop reading.
				break;

			} else {
				// not EOL, so append to buffer.
				$buffer .= $character;

			}
		}

		// return the line buffer.
		return $buffer;

	}
?>
